@@ -8,9 +8,9 @@ __all__ = ('is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'quiet_errors', 'config', '__version__', '__support__',
            'doi', 'ren', 'ISBN13', 'ISBNToolsException', 'ISBNLibException',
            'NotRecognizedServiceError', 'NotValidISBNError',
-           'PluginNotLoadedError')
+           'PluginNotLoadedError', 'goom')
 
-__version__ = '3.3.9'                               # <-- literal IDs
+__version__ = '3.4.1'                               # <-- literal IDs
 __support__ = 'py26, py27, py33, py34, pypy'        # <-- literal IDs
 
 import logging as _logging
@@ -37,6 +37,7 @@ from ._core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
                     canonical, notisbn, get_isbnlike, get_canonical_isbn,
                     EAN13)
 from ._ext import (mask, meta, info, editions, isbn_from_words, doi, ren)
+from ._goom import query as goom
 
 # alias
 ISBN13 = EAN13
